// this function verifies disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired)
{
  var spaceAvailable;

  // Get the available disk space on the given path
  spaceAvailable = fileGetDiskSpaceAvailable(dirPath);

  // Convert the available disk space into kilobytes
  spaceAvailable = parseInt(spaceAvailable / 1024);

  // do the verification
  if(spaceAvailable < spaceRequired)
  {
    logComment("Insufficient disk space: " + dirPath);
    logComment("  required : " + spaceRequired + " kB");
    logComment("  available: " + spaceAvailable + " kB");
    return(false);
  }

  return(true);
}

// this function deletes a file if it exists
function deleteThisFile(dirKey, file)
{
  var fFileToDelete;

  fFileToDelete = getFolder(dirKey, file);
  logComment(file + " file: " + fFileToDelete);
  if(File.exists(fFileToDelete))
  {
    fileDelete(fFileToDelete);
    return(true);
  }
  else
    return(false);
}

// this function deletes a folder (recursively) if it exists
function deleteThisFolder(dirKey, folder)
{
  var fToDelete;

  fToDelete = getFolder(dirKey, folder);
  logComment(folder + " folder: " + fToDelete);
  if(File.exists(fToDelete))
  {
    File.dirRemove(fToDelete, true);
    return(true);
  }
  else
    return(false);
}

// OS type detection
// which platform?
function getPlatform()
{
  var platformStr;
  var platformNode;

  if('platform' in Install)
  {
    platformStr = new String(Install.platform);

    if (!platformStr.search(/^Macintosh/))
      platformNode = 'mac';
    else if (!platformStr.search(/^Win/))
      platformNode = 'win';
    else if (!platformStr.search(/^OS\/2/))
      platformNode = 'win';
    else
      platformNode = 'unix';
  }
  else
  {
    var fOSMac  = getFolder("Mac System");
    var fOSWin  = getFolder("Win System");

    logComment("fOSMac: "  + fOSMac);
    logComment("fOSWin: "  + fOSWin);

    if(fOSMac != null)
      platformNode = 'mac';
    else if(fOSWin != null)
      platformNode = 'win';
    else
      platformNode = 'unix';
  }

  return platformNode;
}

function updateWinReg4Ren8dot3() 
{
  var fProgram      = getFolder("Program");
  var fTemp         = getFolder("Temporary");

  //Notes:
  // can't use a double backslash before subkey - Windows already puts it in.			
  // subkeys have to exist before values can be put in.
  var subkey;  // the name of the subkey you are poking around in
  var valname; // the name of the value you want to look at
  var value;   // the data in the value you want to look at.
  var winreg = getWinRegistry() ;

  if(winreg != null) 
  {
    // Here, we get the current version.
    winreg.setRootKey(winreg.HKEY_CURRENT_USER) ;  // CURRENT_USER
    subkey  = "SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\RunOnce" ;

    winreg.createKey(subkey,"");
    valname = "ren8dot3";
    value   = fProgram + "ren8dot3.exe " + fTemp + "ren8dot3.ini";
    err     = winreg.setValueString(subkey, valname, value);
  }
}

function prepareRen8dot3(listLongFilePaths)
{
  var fTemp                 = getFolder("Temporary");
  var fProgram              = getFolder("Program");
  var fRen8dot3Ini          = getWinProfile(fTemp, "ren8dot3.ini");
  var bIniCreated           = false;
  var fLongFilePath;
  var sShortFilePath;

  if(fRen8dot3Ini != null)
  {
    for(i = 0; i < listLongFilePaths.length; i++)
    {
      fLongFilePath   = getFolder(fProgram, listLongFilePaths[i]);
      sShortFilePath  = File.windowsGetShortName(fLongFilePath);
      if(sShortFilePath)
      {
        fRen8dot3Ini.writeString("rename", sShortFilePath, fLongFilePath);
        bIniCreated = true;
      }
    }

    if(bIniCreated)
      updateWinReg4Ren8dot3() ;
  }

  return(0);
}

///////////////////////////// main //////////////////////////////////
var platformNode, err;

platformNode = getPlatform();
logComment("initInstall: platformNode=" + platformNode);

// ----LOCALIZATION NOTE: translate only these ------
var prettyName = "Italian (it-IT) Language Pack";
var langcode = "it";
var regcode = "IT";
// --- END LOCALIZABLE STUFF ---
var requiredSpace = 380;     //in kBytes
var langpackVer = "1.4rc2";
// --- END MODIFIABLE STUFF ---

var chromeNode = langcode + "-" + regcode;
var regstrnName = "locales/mozilla/" + chromeNode;
var localeName = "locale/" + chromeNode + "/";
var regionName = "locale/" + regcode + "/";

err = initInstall(prettyName, regstrnName, langpackVer); 
logComment("initInstall: " + err);

var destinationType = "Program";
var basefolder = getFolder(destinationType);
var chromeType = LOCALE;
logComment("Base installation folder: " + basefolder);

if(verifyDiskSpace(basefolder, requiredSpace))
{
  if (platformNode == "unix") chromeType |= DELAYED_CHROME;
  err = addDirectory("",          // Insertion point in the registry for ver.
                     "bin",       // Dir name in jar to extract 
                     basefolder,  // Base dir where to put these files
                     "");         // Relative path from the prev.param.
  logComment("addDirectory() returned: " + err);

  if (err!=SUCCESS)
  { // can't install globally, try installing to the profile
    resetError();
    chromeType = LOCALE|PROFILE_CHROME;
    destinationType = "Profile";
    basefolder = getFolder(destinationType);
    logComment("Binaries folder installation, failed. Trying to install to user profile: " + basefolder);
    err = addDirectory("","bin",basefolder,"");
    logComment("addDirectory() in profile returned: " + err);
  }
}
else if (verifyDiskSpace(basefolder, requiredSpace))
{   //Not enough room in the binaries folder, try to user profile instead
    resetError();
    chromeType = LOCALE|PROFILE_CHROME;
    destinationType = "Profile";
    basefolder = getFolder(destinationType);
    logComment("Binaries folder installation, full. Trying to install to user profile: " + basefolder);
    err = addDirectory("","bin",basefolder,"");
    logComment("addDirectory() in profile returned: " + err);
}
else alert('Not enough free space!');

  setPackageFolder(basefolder);
 
  // check return value
if ((err == SUCCESS) || (err == REBOOT_NEEDED))
{
  if (err==REBOOT_NEEDED) resetError();
  // get archives path object and register chrome
  var lpf = getFolder(basefolder, "chrome/"+chromeNode+".jar");
  var rpf = getFolder(basefolder, "chrome/"+regcode+".jar");

//registerChrome(LOCALE[|PROFILE_CHROME], path/chrome/en-US.jar, "/locale/en-US/global/");
// currently 19 - help, Xplatform packages items
  registerChrome(chromeType, lpf, localeName + "autoconfig/");
  registerChrome(chromeType, lpf, localeName + "communicator/");
  registerChrome(chromeType, lpf, localeName + "content-packs/");
  registerChrome(chromeType, lpf, localeName + "cookie/");
  registerChrome(chromeType, lpf, localeName + "editor/");
  registerChrome(chromeType, lpf, localeName + "global/");
  //registerChrome(chromeType, lpf, localeName + "help/");
  registerChrome(chromeType, lpf, localeName + "messenger/");
  registerChrome(chromeType, lpf, localeName + "messenger-smime/");
  registerChrome(chromeType, lpf, localeName + "mozldap/");
  registerChrome(chromeType, lpf, localeName + "navigator/");
  registerChrome(chromeType, lpf, localeName + "necko/");
  registerChrome(chromeType, lpf, localeName + "p3p/");
  registerChrome(chromeType, lpf, localeName + "pipnss/");
  registerChrome(chromeType, lpf, localeName + "pippki/");
  registerChrome(chromeType, lpf, localeName + "wallet/");
  registerChrome(chromeType, lpf, localeName + "chatzilla/");
  registerChrome(chromeType, lpf, localeName + "inspector/");
  registerChrome(chromeType, lpf, localeName + "venkman/");
    
  registerChrome(chromeType, rpf, regionName + "communicator-region/");
  registerChrome(chromeType, rpf, regionName + "editor-region/");
  registerChrome(chromeType, rpf, regionName + "global-region/");
  registerChrome(chromeType, rpf, regionName + "messenger-region/");
  registerChrome(chromeType, rpf, regionName + "navigator-region/");

  //peek another XPI folder (/mac,/unix or /win) and install plaform stuff
  err = addDirectory("",platformNode,basefolder,"");
  logComment('addDirectory return code on platform '+platformNode+' : '+err);
  if (err==REBOOT_NEEDED) resetError();
  var ppf = getFolder(basefolder, "chrome/"+langcode+"-"+platformNode+".jar");

  var XULFastloadFilename = "";
  switch (platformNode) {
   case "mac":
    registerChrome(chromeType, ppf, localeName + "global-platform/");
    registerChrome(chromeType, ppf, localeName + "communicator-platform/");
    registerChrome(chromeType, ppf, localeName + "navigator-platform/");
    XULFastloadFilename = "XUL FastLoad File";
    break;
   case "unix":
    registerChrome(chromeType, ppf, localeName + "global-platform/");
    registerChrome(chromeType, ppf, localeName + "communicator-platform/");
    registerChrome(chromeType, ppf, localeName + "navigator-platform/");
    XULFastloadFilename = "XUL.mfasl";
    break;
   case "win":
    registerChrome(chromeType, ppf, localeName + "global-platform/");
    registerChrome(chromeType, ppf, localeName + "communicator-platform/");
    registerChrome(chromeType, ppf, localeName + "navigator-platform/");
    registerChrome(chromeType, ppf, localeName + "messenger-mapi/");
    XULFastloadFilename = "XUL.mfl";
    break;
  }

  err = performInstall(); 
  logComment("performInstall() returned: " + err);
  
  if (platformNode == "mac")
    err = "Installazione completata.\nSi pu selezionare la lingua "+
          "italiana in Mozilla | Preferences\n| Appearance | "+
          "Language/Contents Pack.";
  else
    err = "Installazione completata.\nSi pu selezionare la lingua "+
          "italiana in Edit | Preferences\n| Appearance | "+
          "Language/Contents Pack.";
  if (err==REBOOT_NEEDED) err += "\n\nPer completare l'installazione  "
           +"richiesto il riavvio di Mozilla.";
           
  /// !!!!!!!! Warn the user to manually delete the XUL FastLoad file
/*  err += "\n\n[NOTA]: A causa di un bug di Mozilla 1.4,  necessario "
       + " che dopo aver selezionato la lingua nelle Preferenze, si "
       + "esca da Mozilla e venga cancellato manualmente il file "
       + "\""+XULFastloadFilename+"\" dalla cartella del proprio "
       + "profilo utente." */
           
  alert (err);

}
else
{
  cancelInstall(err);
  logComment("cancelInstall due to error: " + err);
  alert ("L'installazione non  andata a buon fine.\nControllare di"+
         " avere accesso in scrittura nella cartella\ndel proprio profilo"+
         " utente, e riprovare.\nSe non  questa la causa del fallimento,"+
         " siete pregati\ndi comunicare gli errori riportati nel file"+
         " 'install.log' agli\nautori di questo pacchetto.\n"+
         "\nhttp://members.xoom.virgilio.it/mozdoesit/");
}

// end main
